@@ -14,19 +14,20 @@ TODO:
 - Tests Tests Tests!
 """
 import astropy.units as u
-from astropy.units.quantity import Quantity
 import numpy as np
 from astropy.coordinates import (
+    ITRS,
+    AffineTransform,
     AltAz,
     BaseCoordinateFrame,
     CartesianRepresentation,
     CoordinateAttribute,
+    EarthLocationAttribute,
     FunctionTransform,
     RepresentationMapping,
     frame_transform_graph,
-    AffineTransform,
 )
-from numpy import cos, sin
+from astropy.units.quantity import Quantity
 
 __all__ = [
     "GroundFrame",
@@ -36,6 +37,23 @@ __all__ = [
 ]
 
 
+def _altaz_to_earthlocation(altaz):
+    local_itrs = altaz.transform_to(ITRS(location=altaz.location))
+    itrs = ITRS(local_itrs.cartesian + altaz.location.get_itrs().cartesian)
+    return itrs.earth_location
+
+
+def _earthlocation_to_altaz(location, reference_location):
+    # See
+    # https://docs.astropy.org/en/stable/coordinates/common_errors.html#altaz-calculations-for-earth-based-objects
+    # for why this is necessary and we cannot just do
+    # `get_itrs().transform_to(AltAz())`
+    itrs_cart = location.get_itrs().cartesian
+    itrs_ref_cart = reference_location.get_itrs().cartesian
+    local_itrs = ITRS(itrs_cart - itrs_ref_cart, location=reference_location)
+    return local_itrs.transform_to(AltAz(location=reference_location))
+
+
 class GroundFrame(BaseCoordinateFrame):
     """Ground coordinate frame.  The ground coordinate frame is a simple
     cartesian frame describing the 3 dimensional position of objects
@@ -49,6 +67,44 @@ class GroundFrame(BaseCoordinateFrame):
     """
 
     default_representation = CartesianRepresentation
+    reference_location = EarthLocationAttribute()
+
+    def to_earth_location(self):
+        """Convert this GroundFrame coordinate into an `astropy.coordinates.EarthLocation`
+
+        This requires that the ``reference_location`` is set.
+        """
+        # in astropy, x points north, y points east, so we need a minus for y.
+        cart = CartesianRepresentation(self.x, -self.y, self.z)
+        altaz = AltAz(cart, location=self.reference_location)
+        return _altaz_to_earthlocation(altaz)
+
+    @classmethod
+    def from_earth_location(cls, location, reference_location):
+        """
+        Convert `~astropy.coordinates.EarthLocation` into Groundframe.
+
+        Parameters
+        ----------
+        location : astropy.coordinates.EarthLocation
+            The location to convert
+        reference_location : astropy.coordinates.EarthLocation
+            Reference location for the GroundFrame
+
+        Returns
+        -------
+        ground_frame : GroundFrame
+            EarthLocation converted to GroundFrame
+        """
+        altaz = _earthlocation_to_altaz(location, reference_location)
+        x, y, z = altaz.cartesian.xyz
+        # in astropy, x points north, y points east, so we need a minus for y.
+        return GroundFrame(x=x, y=-y, z=z, reference_location=reference_location)
+
+    @property
+    def observation_level(self):
+        """Height of the reference location"""
+        return self.reference_location.height
 
 
 class EastingNorthingFrame(BaseCoordinateFrame):
@@ -60,6 +116,7 @@ class EastingNorthingFrame(BaseCoordinateFrame):
     """
 
     default_representation = CartesianRepresentation
+    reference_location = EarthLocationAttribute()
 
     frame_specific_representation_info = {
         CartesianRepresentation: [
@@ -69,6 +126,28 @@ class EastingNorthingFrame(BaseCoordinateFrame):
         ]
     }
 
+    def to_earth_location(self):
+        # in astropy, x points north, y points east
+        cart = CartesianRepresentation(self.northing, self.easting, self.height)
+        altaz = AltAz(cart, location=self.reference_location)
+        return _altaz_to_earthlocation(altaz)
+
+    @classmethod
+    def from_earth_location(cls, location, reference_location):
+        altaz = _earthlocation_to_altaz(location, reference_location)
+        x, y, z = altaz.cartesian.xyz
+        # in astropy, x points north, y points east
+        return GroundFrame(
+            northing=x,
+            easting=y,
+            height=z,
+            reference_location=reference_location,
+        )
+
+    @property
+    def observation_level(self):
+        return self.reference_location.height
+
 
 class TiltedGroundFrame(BaseCoordinateFrame):
     """Tilted ground coordinate frame.  The tilted ground coordinate frame
@@ -91,7 +170,7 @@ class TiltedGroundFrame(BaseCoordinateFrame):
     pointing_direction = CoordinateAttribute(default=None, frame=AltAz)
 
 
-def get_shower_trans_matrix(azimuth, altitude):
+def _get_shower_trans_matrix(azimuth, altitude, inverse=False):
     """Get Transformation matrix for conversion from the ground system to
     the Tilted system and back again (This function is directly lifted
     from read_hess, probably could be streamlined using python
@@ -99,20 +178,19 @@ def get_shower_trans_matrix(azimuth, altitude):
 
     Parameters
     ----------
-    azimuth: float
-        Azimuth angle of the tilted system used
-    altitude: float
-        Altitude angle of the tilted system used
+    azimuth: float or ndarray
+        Azimuth angle in radians of the tilted system used
+    altitude: float or ndarray
+        Altitude angle in radiuan of the tilted system used
 
     Returns
     -------
     trans: 3x3 ndarray transformation matrix
     """
-
-    cos_z = sin(altitude)
-    sin_z = cos(altitude)
-    cos_az = cos(azimuth)
-    sin_az = sin(azimuth)
+    cos_z = np.sin(altitude)  # this is the same as np.cos(zenith) but faster
+    sin_z = np.cos(altitude)
+    cos_az = np.cos(azimuth)
+    sin_az = np.sin(azimuth)
 
     trans = np.array(
         [
@@ -123,9 +201,28 @@ def get_shower_trans_matrix(azimuth, altitude):
         dtype=np.float64,
     )
 
+    if inverse:
+        return np.swapaxes(trans, 0, 1)
+
     return trans
 
 
+def _get_xyz(coord):
+    """
+    Essentially the same as coord.cartesian.xyz, but much faster by
+    avoiding some astropy bottlenecks.
+    """
+    # this is a speed optimization. Much faster to use data if already a
+    # Cartesian object
+    if isinstance(coord.data, CartesianRepresentation):
+        cart = coord.data
+    else:
+        cart = coord.cartesian
+
+    # this is ~5x faster then cart.xyz
+    return u.Quantity([cart.x, cart.y, cart.z])
+
+
 @frame_transform_graph.transform(FunctionTransform, GroundFrame, TiltedGroundFrame)
 def ground_to_tilted(ground_coord, tilted_frame):
     """
@@ -142,18 +239,17 @@ def ground_to_tilted(ground_coord, tilted_frame):
     -------
     SkyCoordinate transformed to `tilted_frame` coordinates
     """
-    x_grd, y_grd, z_grd = ground_coord.cartesian.xyz
+    xyz_grd = _get_xyz(ground_coord)
 
+    # convert to rad first and substract. Faster than .zen
     altitude = tilted_frame.pointing_direction.alt.to_value(u.rad)
     azimuth = tilted_frame.pointing_direction.az.to_value(u.rad)
 
-    trans = get_shower_trans_matrix(azimuth, altitude)
+    rotation_matrix = _get_shower_trans_matrix(azimuth, altitude)
 
-    x_tilt = trans[0, 0] * x_grd + trans[0, 1] * y_grd + trans[0, 2] * z_grd
-    y_tilt = trans[1, 0] * x_grd + trans[1, 1] * y_grd + trans[1, 2] * z_grd
-    z_tilt = trans[2, 0] * x_grd + trans[2, 1] * y_grd + trans[2, 2] * z_grd
+    vec = np.einsum("ij...,j...->i...", rotation_matrix, xyz_grd)
 
-    representation = CartesianRepresentation(x_tilt, y_tilt, z_tilt)
+    representation = CartesianRepresentation(*vec)
 
     return tilted_frame.realize_frame(representation)
 
@@ -174,20 +270,19 @@ def tilted_to_ground(tilted_coord, ground_frame):
     -------
     GroundFrame coordinates
     """
-    x_tilt, y_tilt, z_tilt = tilted_coord.cartesian.xyz
+    xyz_tilt = _get_xyz(tilted_coord)
 
-    altitude = tilted_coord.pointing_direction.alt.to(u.rad)
-    azimuth = tilted_coord.pointing_direction.az.to(u.rad)
+    altitude = tilted_coord.pointing_direction.alt.to_value(u.rad)
+    azimuth = tilted_coord.pointing_direction.az.to_value(u.rad)
 
-    trans = get_shower_trans_matrix(azimuth, altitude)
+    rotation_matrix = _get_shower_trans_matrix(azimuth, altitude, inverse=True)
 
-    x_grd = trans[0][0] * x_tilt + trans[1][0] * y_tilt + trans[2][0] * z_tilt
-    y_grd = trans[0][1] * x_tilt + trans[1][1] * y_tilt + trans[2][1] * z_tilt
-    z_grd = trans[0][2] * x_tilt + trans[1][2] * y_tilt + trans[2][2] * z_tilt
+    vec = np.einsum("ij...,j...->i...", rotation_matrix, xyz_tilt)
 
-    representation = CartesianRepresentation(x_grd, y_grd, z_grd)
+    representation = CartesianRepresentation(*vec)
 
     grd = ground_frame.realize_frame(representation)
+
     return grd
 
 
@@ -215,14 +310,19 @@ def project_to_ground(tilt_system):
     y_initial = ground_system.y.value
     z_initial = ground_system.z.value
 
-    trans = get_shower_trans_matrix(
-        tilt_system.pointing_direction.az, tilt_system.pointing_direction.alt
+    trans = _get_shower_trans_matrix(
+        tilt_system.pointing_direction.az.to_value(u.rad),
+        tilt_system.pointing_direction.alt.to_value(u.rad),
     )
 
     x_projected = x_initial - trans[2][0] * z_initial / trans[2][2]
     y_projected = y_initial - trans[2][1] * z_initial / trans[2][2]
 
-    return GroundFrame(x=x_projected * unit, y=y_projected * unit, z=0 * unit)
+    return GroundFrame(
+        x=u.Quantity(x_projected, unit),
+        y=u.Quantity(y_projected, unit),
+        z=u.Quantity(0, unit),
+    )
 
 
 @frame_transform_graph.transform(FunctionTransform, GroundFrame, GroundFrame)
