@@ -1,8 +1,9 @@
-import numpy as np
 import astropy.units as u
-from astropy.coordinates import SkyCoord, EarthLocation, AltAz
+import numpy as np
+from astropy.coordinates import AltAz, EarthLocation, SkyCoord
 from astropy.time import Time
 from pytest import approx, raises
+
 from ctapipe.coordinates import altaz_to_righthanded_cartesian
 
 location = EarthLocation.of_site("Roque de los Muchachos")
@@ -236,15 +237,19 @@ def test_ground_to_tilt_many_to_one():
 def test_ground_to_tilt_many_to_many():
     from ctapipe.coordinates import GroundFrame, TiltedGroundFrame
 
-    # define ground coordinate
-    grd_coord = GroundFrame(x=[1, 1] * u.m, y=[2, 2] * u.m, z=[0, 0] * u.m)
+    ground = GroundFrame(x=[1, 2] * u.m, y=[2, 1] * u.m, z=[3, 3] * u.m)
     pointing_direction = SkyCoord(
-        alt=[90, 90, 90], az=[0, 0, 90], frame=AltAz(), unit=u.deg
+        alt=[90, 90, 90],
+        az=[0, 90, 180],
+        frame=AltAz(),
+        unit=u.deg,
     )
 
-    with raises(ValueError):
-        # there will be a shape mismatch in matrix multiplication
-        grd_coord.transform_to(TiltedGroundFrame(pointing_direction=pointing_direction))
+    tilted = ground[:, np.newaxis].transform_to(
+        TiltedGroundFrame(pointing_direction=pointing_direction)
+    )
+
+    assert tilted.shape == (2, 3)
 
 
 def test_camera_missing_focal_length():
@@ -281,9 +286,30 @@ def test_ground_frame_roundtrip():
     assert u.isclose(coord.z, back.z, atol=1e-12 * u.m)
 
 
+def test_ground_to_tilt_many_to_many_roundtrip():
+    from ctapipe.coordinates import GroundFrame, TiltedGroundFrame
+
+    ground = GroundFrame(x=[1, 2] * u.m, y=[2, 1] * u.m, z=[3, 3] * u.m)
+    pointing_direction = SkyCoord(
+        alt=[90, 90, 90],
+        az=[0, 0, 180],
+        frame=AltAz(),
+        unit=u.deg,
+    )
+
+    tilted = ground[:, np.newaxis].transform_to(
+        TiltedGroundFrame(pointing_direction=pointing_direction)
+    )
+    back = tilted[:, 0].transform_to(GroundFrame())
+
+    assert u.isclose(ground.x, back.x, atol=1e-12 * u.m).all()
+    assert u.isclose(ground.y, back.y, atol=1e-12 * u.m).all()
+    assert u.isclose(ground.z, back.z, atol=1e-12 * u.m).all()
+
+
 def test_ground_to_eastnorth_roundtrip():
     """Check Ground to EastingNorthing and the round-trip"""
-    from ctapipe.coordinates import GroundFrame, EastingNorthingFrame
+    from ctapipe.coordinates import EastingNorthingFrame, GroundFrame
 
     ground = SkyCoord(
         x=[1, 2, 3] * u.m, y=[-2, 5, 2] * u.m, z=[1, -1, 2] * u.m, frame=GroundFrame()
@@ -297,4 +323,4 @@ def test_ground_to_eastnorth_roundtrip():
 
     assert u.isclose(ground.x, ground2.x).all()
     assert u.isclose(ground.y, ground2.y).all()
-    assert u.isclose(ground.z, ground2.z).all()
\ No newline at end of file
+    assert u.isclose(ground.z, ground2.z).all()
