@@ -3,11 +3,13 @@
 Core functionality of ctapipe
 """
 
-from .component import Component, TelescopeComponent, non_abstract_children
-from .container import Container, Field, DeprecatedField, Map, FieldValidationError
+from .component import Component, non_abstract_children
+from .container import Container, DeprecatedField, Field, FieldValidationError, Map
+from .feature_generator import FeatureGenerator
 from .provenance import Provenance, get_module_version
+from .qualityquery import QualityCriteriaError, QualityQuery
+from .telescope_component import TelescopeComponent
 from .tool import Tool, ToolConfigurationError, run_tool
-from .qualityquery import QualityQuery, QualityCriteriaError
 
 __all__ = [
     "Component",
@@ -15,6 +17,7 @@ __all__ = [
     "Container",
     "Tool",
     "Field",
+    "FeatureGenerator",
     "DeprecatedField",
     "Map",
     "Provenance",
