@@ -17,15 +17,18 @@ from importlib import import_module
 from os.path import abspath
 from pathlib import Path
 
-import pkg_resources
 import psutil
 from astropy.time import Time
-from pkg_resources import get_distribution
 
 import ctapipe
 
 from .support import Singleton
 
+if sys.version_info < (3, 9):
+    from importlib_metadata import distributions, version
+else:
+    from importlib.metadata import distributions, version
+
 log = logging.getLogger(__name__)
 
 __all__ = ["Provenance"]
@@ -52,7 +55,7 @@ def get_module_version(name):
         return module.__version__
     except AttributeError:
         try:
-            return get_distribution(name).version
+            return version(name)
         except Exception:
             return "unknown"
     except ImportError:
@@ -83,6 +86,16 @@ class Provenance(metaclass=Singleton):
         self._activities.append(activity)
         log.debug(f"started activity: {activity_name}")
 
+    def _get_current_or_start_activity(self):
+        if self.current_activity is None:
+            log.info(
+                "No activity has been explicitly started, starting new default activity."
+                " Consider calling Provenance().start_activity(<name>) explicitly."
+            )
+            self.start_activity()
+
+        return self.current_activity
+
     def add_input_file(self, filename, role=None):
         """register an input to the current activity
 
@@ -93,11 +106,12 @@ class Provenance(metaclass=Singleton):
         role: str
             role this input file satisfies (optional)
         """
-        self.current_activity.register_input(abspath(filename), role=role)
+        activity = self._get_current_or_start_activity()
+        activity.register_input(abspath(filename), role=role)
         log.debug(
-            "added input entity '{}' to activity: '{}'".format(
-                filename, self.current_activity.name
-            )
+            "added input entity '%s' to activity: '%s'",
+            filename,
+            activity.name,
         )
 
     def add_output_file(self, filename, role=None):
@@ -112,11 +126,12 @@ class Provenance(metaclass=Singleton):
             role this output file satisfies (optional)
 
         """
-        self.current_activity.register_output(abspath(filename), role=role)
+        activity = self._get_current_or_start_activity()
+        activity.register_output(abspath(filename), role=role)
         log.debug(
-            "added output entity '{}' to activity: '{}'".format(
-                filename, self.current_activity.name
-            )
+            "added output entity '%s' to activity: '%s'",
+            filename,
+            activity.name,
         )
 
     def add_config(self, config):
@@ -128,7 +143,13 @@ class Provenance(metaclass=Singleton):
         config: dict
             configuration parameters
         """
-        self.current_activity.register_config(config)
+        activity = self._get_current_or_start_activity()
+        activity.register_config(config)
+        log.debug(
+            "added config entity '%s' to activity: '%s'",
+            config,
+            activity.name,
+        )
 
     def finish_activity(self, status="completed", activity_name=None):
         """end the current activity"""
@@ -153,9 +174,8 @@ class Provenance(metaclass=Singleton):
     @property
     def current_activity(self):
         if len(self._activities) == 0:
-            log.debug("No activity has been started... starting a default one")
-            self.start_activity()
-        return self._activities[-1]  # current activity as at the top of stack
+            return None
+        return self._activities[-1]  # current activity is at the top of stack
 
     @property
     def finished_activities(self):
@@ -286,8 +306,8 @@ class _ActivityProvenance:
 
 def _get_python_packages():
     return [
-        {"name": p.project_name, "version": p.version, "path": p.module_path}
-        for p in sorted(pkg_resources.working_set, key=lambda p: p.project_name)
+        {"name": p.name, "version": p.version}
+        for p in sorted(distributions(), key=lambda d: d.name)
     ]
 
 
