@@ -28,9 +28,9 @@ class QualityQuery(Component):
         Tuple(Unicode(), Unicode()),
         help=(
             "list of tuples of ('<description', 'expression string') to accept "
-            "(select) a given data value.  E.g. `[('mycut', 'x > 3'),]. "
-            "You may use `numpy` as `np` and `astropy.units` as `u`, but no other"
-            " modules."
+            "(select) a given data value.  E.g. ``[('mycut', 'x > 3'),]``. "
+            "You may use ``numpy`` as ``np`` and ``astropy.units`` as ``u``,"
+            " but no other modules."
         ),
     ).tag(config=True)
 
@@ -41,10 +41,7 @@ class QualityQuery(Component):
         self.criteria_names = [n for (n, _) in self.quality_criteria]
         self.expressions = [e for (_, e) in self.quality_criteria]
 
-        self.engine = ExpressionEngine(
-            parent=self,
-            expressions=self.quality_criteria,
-        )
+        self.engine = ExpressionEngine(self.quality_criteria)
         for _, expr in self.quality_criteria:
             if "lambda" in expr:
                 raise ValueError(
