@@ -9,7 +9,9 @@ from astropy.table import vstack
 from astropy.utils.diff import report_diff_values
 
 from ctapipe.core import run_tool
+from ctapipe.io import TableLoader
 from ctapipe.io.astropy_helpers import read_table
+from ctapipe.io.tests.test_astropy_helpers import assert_table_equal
 from ctapipe.tools.process import ProcessorTool
 
 try:
@@ -26,7 +28,7 @@ def run_stage1(input_path, cwd, output_path=None):
             tempfile.NamedTemporaryFile(suffix=".dl1.h5", dir=cwd).name
         ).absolute()
 
-    ret = run_tool(
+    run_tool(
         ProcessorTool(),
         argv=[
             f"--config={config}",
@@ -38,20 +40,20 @@ def run_stage1(input_path, cwd, output_path=None):
             "--max-events=5",
         ],
         cwd=cwd,
+        raises=True,
     )
-    assert ret == 0, "Running stage1 failed"
 
 
 def test_simple(tmp_path, dl1_file, dl1_proton_file):
     from ctapipe.tools.merge import MergeTool
 
     output = tmp_path / "merged_simple.dl1.h5"
-    ret = run_tool(
+    run_tool(
         MergeTool(),
         argv=[str(dl1_file), str(dl1_proton_file), f"--output={output}", "--overwrite"],
         cwd=tmp_path,
+        raises=True,
     )
-    assert ret == 0
     run_stage1(output, cwd=tmp_path)
 
 
@@ -62,23 +64,25 @@ def test_pattern(tmp_path: Path, dl1_file, dl1_proton_file):
     open(dl1_file.parent / "foo.h5", "w").close()
 
     # copy to make sure we don't have other files in the dl1 dir disturb this
+    indir = tmp_path / "input"
+    indir.mkdir()
     for f in (dl1_file, dl1_proton_file):
-        shutil.copy(f, tmp_path)
+        shutil.copy(f, indir)
 
     output = tmp_path / "merged_pattern.dl1.h5"
-    ret = run_tool(
+    run_tool(
         tool=MergeTool(),
         argv=[
             "-i",
-            str(tmp_path),
+            str(indir),
             "-p",
             "*.dl1.h5",
             f"--output={output}",
             "--overwrite",
         ],
         cwd=tmp_path,
+        raises=True,
     )
-    assert ret == 0
     run_stage1(output, cwd=tmp_path)
 
 
@@ -87,18 +91,19 @@ def test_skip_images(tmp_path, dl1_file, dl1_proton_file):
 
     # create a second file so we can test the patterns
     output = tmp_path / "merged_no_images.dl1.h5"
-    ret = run_tool(
+    run_tool(
         MergeTool(),
         argv=[
             str(dl1_file),
             str(dl1_proton_file),
             f"--output={output}",
-            "--skip-images",
+            "--no-dl1-images",
+            "--no-true-images",
             "--overwrite",
         ],
         cwd=tmp_path,
+        raises=True,
     )
-    assert ret == 0
 
     with tables.open_file(output, "r") as f:
         assert "images" not in f.root.dl1.event.telescope
@@ -110,47 +115,19 @@ def test_skip_images(tmp_path, dl1_file, dl1_proton_file):
     assert "true_image_sum" in t.colnames
 
 
-def test_allowed_tels(tmp_path, dl1_file, dl1_proton_file):
-    from ctapipe.instrument import SubarrayDescription
-    from ctapipe.tools.merge import MergeTool
-
-    # create file to test 'allowed-tels' option
-    output = tmp_path / "merged_allowed_tels.dl1.h5"
-
-    allowed_tels = {25, 125}
-
-    argv = [str(dl1_file), str(dl1_proton_file), f"--output={output}", "--overwrite"]
-    for tel_id in allowed_tels:
-        argv.append(f"--allowed-tels={tel_id}")
-
-    ret = run_tool(MergeTool(), argv=argv, cwd=tmp_path)
-    assert ret == 0
-
-    s = SubarrayDescription.from_hdf(output)
-    assert s.tel.keys() == allowed_tels
-
-    tel_keys = {f"tel_{tel_id:03d}" for tel_id in allowed_tels}
-    with tables.open_file(output) as f:
-        assert set(f.root.dl1.event.telescope.parameters._v_children).issubset(tel_keys)
-        assert set(f.root.dl1.event.telescope.images._v_children).issubset(tel_keys)
-        assert set(f.root.dl1.monitoring.telescope.pointing._v_children).issubset(
-            tel_keys
-        )
-
-
 def test_dl2(tmp_path, dl2_shower_geometry_file, dl2_proton_geometry_file):
     from ctapipe.tools.merge import MergeTool
 
     output = tmp_path / "merged.dl2.h5"
-    ret = run_tool(
+    run_tool(
         MergeTool(),
         argv=[
             f"--output={output}",
             str(dl2_shower_geometry_file),
             str(dl2_proton_geometry_file),
         ],
+        raises=True,
     )
-    assert ret == 0, f"Running merge for dl2 files failed with exit code {ret}"
 
     table1 = read_table(
         dl2_shower_geometry_file, "/dl2/event/subarray/geometry/HillasReconstructor"
@@ -182,3 +159,33 @@ def test_dl2(tmp_path, dl2_shower_geometry_file, dl2_proton_geometry_file):
 
     assert len(obs) == 2, "should have two OB entries"
     assert len(sbs) == 2, "should have two SB entries"
+
+    # regression test for #2048
+    loader = TableLoader(output, load_dl2=True, load_simulated=True)
+    tel_events = loader.read_telescope_events()
+    assert "true_impact_distance" in tel_events.colnames
+    # regression test for #2051
+    assert "HillasReconstructor_tel_impact_distance" in tel_events.colnames
+
+
+def test_muon(tmp_path, dl1_muon_output_file):
+    from ctapipe.tools.merge import MergeTool
+
+    output = tmp_path / "muon_merged.dl2.h5"
+    run_tool(
+        MergeTool(),
+        argv=[
+            f"--output={output}",
+            str(dl1_muon_output_file),
+            str(dl1_muon_output_file),
+        ],
+        raises=True,
+    )
+
+    table = read_table(output, "/dl1/event/telescope/muon/tel_001")
+    input_table = read_table(dl1_muon_output_file, "/dl1/event/telescope/muon/tel_001")
+
+    n_input = len(input_table)
+    assert len(table) == 2 * n_input
+    assert_table_equal(table[:n_input], input_table)
+    assert_table_equal(table[n_input:], input_table)
