@@ -7,6 +7,7 @@ from .datasets import (
     get_table_dataset,
     get_dataset_path,
     find_in_path,
+    resource_file,
 )
 from .astro import get_bright_stars
 from .index_finder import IndexFinder
@@ -21,6 +22,7 @@ __all__ = [
     "get_table_dataset",
     "get_dataset_path",
     "find_in_path",
+    "resource_file",
     "get_bright_stars",
     "IndexFinder",
     "EventTypeFilter",
