@@ -1,7 +1,9 @@
-from ctapipe.instrument import CameraGeometry
 from matplotlib import pyplot as plt
 
-geom = CameraGeometry.from_name("LSTCam")
+from ctapipe.instrument import SubarrayDescription
+
+subarray = SubarrayDescription.read("dataset://gamma_prod5.simtel.zst")
+geom = subarray.tel[1].camera.geometry
 
 plt.figure(figsize=(8, 3))
 plt.subplot(1, 2, 1)
